drain-swamp pretag
===================

Fixes semantic version str. Best practice is to check the semantic version str before using.

.. code-block:: shell

   drain-swamp pretag "0.0.1a2dev3"

0.0.1a2.dev3
